EntityId

Enum EntityId 

pub enum EntityId {
    Global,
    Container(MetaString),
    ContainerImageMetadata(MetaString),
    EcsTask(MetaString),
    KubernetesDeployment(MetaString),
    KubernetesMetadata(MetaString),
    KubernetesNode(MetaString),
    PodUid(MetaString),
    Process(MetaString),
    ContainerInode(u64),
    ContainerPid(u32),
}
An entity identifier.

Variants



Global

The global entity.

Represents the root of the entity hierarchy, which is equivalent to a “global” scope. This is generally used to represent a collection of metadata entries that aren’t associated with any specific entity, but with anything within the workload, such as host or cluster tags.



Container(MetaString)

A container ID.

This is generally a long hexadecimal string, as generally used by container runtimes like containerd.



ContainerImageMetadata(MetaString)

An OCI image manifest digest.



EcsTask(MetaString)

An ECS task ARN.



KubernetesDeployment(MetaString)

A Kubernetes deployment, identified by <namespace>/<name>.



KubernetesMetadata(MetaString)

Kubernetes metadata, such as a namespace path.



KubernetesNode(MetaString)

A Kubernetes node name.



PodUid(MetaString)

A Kubernetes pod UID.

Represents the UUID of a specific Kubernetes pod.



Process(MetaString)

A process identifier reported by the remote tagger.



ContainerInode(u64)

A container inode.

Represents the inode of the cgroups controller for a specific container.



ContainerPid(u32)

A container PID.

Represents the PID of the process within a specific container.

Implementations

Source

impl EntityId

pub fn from_local_data<S>(raw_local_data: S) -> Option<Self>
where S: AsRef<str> + Into<MetaString>,

Creates an EntityId from Local Data.

This method follows the same logic/behavior as the Datadog Agent’s origin detection logic:

  • If the input starts with ci-, we treat it as a container ID.
  • If the input starts with in-, we treat it as a container cgroup controller inode.
  • If the input contains a comma, we split the input and search for either a prefixed container ID or prefixed inode. If both are present, we use the container ID.
  • If the input starts with cid-, we treat it as a container ID.
  • If none of the above conditions are met, we assume the entire input is a container ID.

If the input fails to be parsed in a valid fashion (for example, in- prefix but the remainder isn’t a valid integer), or is empty, None is returned.

pub fn from_pod_uid<S>(pod_uid: S) -> Option<Self>
where S: AsRef<str> + Into<MetaString>,

Creates an EntityId from a Kubernetes pod UID.

If the pod UID value is "none", this will return None.

pub fn try_into_container(self) -> Option<MetaString>

Returns the inner container ID value, if this entity ID is a Container.

Otherwise, None is returned and the original entity ID is consumed.