pub struct HighestPrecedenceEntityIdRef<'a>(/* private fields */);Expand description
A wrapper for entity IDs that sorts them in a manner consistent with the expected precedence of entity IDs.
This type establishes a total ordering over entity IDs based on their logical precedence, which is as follows:
- global (highest precedence)
- pod
- container
- container inode
- container PID (lowest precedence)
Wrapped entity IDs are be sorted highest to lowest precedence. For entity IDs with the same precedence, they’re further ordered by their internal value. For entity IDs with a string identifier, lexicographical ordering is used. For entity IDs with a numeric identifier, numerical ordering is used.